#
# spec file for package fetchmail
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           fetchmail
Version:        6.3.26
Release:        lp151.4.5
Summary:        Full-Featured POP and IMAP Mail Retrieval Daemon
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Utilities
Url:            http://www.fetchmail.info/
Source:         http://sourceforge.net/projects/fetchmail/files/branch_6.3/%{name}-%{version}.tar.xz
Source2:        %{name}.logrotate
Source3:        sysconfig.%{name}
Source4:        http://sourceforge.net/projects/fetchmail/files/branch_6.3/%{name}-%{version}.tar.xz.asc
Source5:        %{name}.keyring
Source6:        %{name}.service
Source7:        %{name}.tmpfiles
Source8:        %{name}.exec
Patch0:         fetchmail-6.3.8-smtp_errors.patch
Patch1:         fetchmail-openssl11.patch
# PATCH-FIX-UPSTREAM bsc#1082694 Fix fetchmailconf to be able to compile with python{2,3}
Patch2:         fetchmail-fetchmailconf-python3-1of3.patch
Patch3:         fetchmail-fetchmailconf-python3-2of3.patch
Patch4:         fetchmail-fetchmailconf-python3-3of3.patch
BuildRequires:  automake
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  opie
BuildRequires:  postfix
BuildRequires:  procmail
BuildRequires:  pwdutils
BuildRequires:  python-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
Requires:       logrotate
Requires(pre):  %fillup_prereq
Requires(pre):  coreutils
Requires(pre):  pwdutils
Suggests:       smtp_daemon
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1315
Requires(pre):	group(daemon)
%endif
%{?systemd_requires}

%description
Fetchmail is a robust and well-documented remote mail retrieval and
forwarding utility intended to be used over on-demand TCP/IP links
(such as SLIP or PPP connections).

Fetchmail retrieves mail from remote mail servers and forwards it to
your local machine's delivery system, so it can be read by normal mail
user agents, such as mutt, elm, pine, (x)emacs/gnus, or mailx.

fetchmailconf, an interactive GUI configurator suitable for end-users,
is included in the fetchmailconf package.

%package -n fetchmailconf
Summary:        Fetchmail Configuration Utility
Group:          Productivity/Networking/Email/Utilities
Requires:       %{name} = %{version}
Requires:       python-tk

%description -n fetchmailconf
A GUI configuration utility for generating fetchmail configuration
files (.fetchmailrc).

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
cp -a %{SOURCE2} %{SOURCE3} .

ACLOCAL="aclocal -I m4 -I m4-local" autoreconf -fvi

%build
export CFLAGS="%{optflags} -fPIE"
%configure \
	--enable-POP2 \
	--enable-RPA \
	--enable-NTLM \
	--enable-SDPS \
	--enable-opie \
	--with-kerberos5 \
        --with-gssapi \
	--with-ssl=%{_prefix}
make %{?_smp_mflags} LDFLAGS="-pie"

%install
%make_install
ln -sf fetchmail.1.gz %{buildroot}/%{_mandir}/man1/fetchmailconf.1.gz
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
cp fetchmail.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/fetchmail
mkdir -p %{buildroot}/sbin
mkdir -p %{buildroot}/%{_unitdir}
mkdir -p %{buildroot}/%{_libexecdir}/tmpfiles.d
install -m 0644 %{SOURCE6} %{buildroot}/%{_unitdir}/%{name}.service
install -m 0644 %{SOURCE7} %{buildroot}/%{_libexecdir}/tmpfiles.d/%{name}.conf
install -m 0755 %{SOURCE8} %{buildroot}/%{_libexecdir}/%{name}-systemd-exec
mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rc%{name}
touch %{buildroot}%{_sysconfdir}/fetchmailrc
mkdir -p %{buildroot}%{_fillupdir}
cp sysconfig.%{name} %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/fetchmail
mkdir -p %{buildroot}%{_localstatedir}/lib/fetchmail
# we don't need this, it's aimed at fetchmail developers
# and rpmlint is complaining that we have a binary in /usr/share
rm -r contrib/gai*
%find_lang %{name}

%pre
/usr/bin/getent passwd fetchmail >/dev/null || \
  /usr/sbin/useradd -r -g daemon -s /bin/false \
  -c "mail retrieval daemon" -d %{_localstatedir}/lib/fetchmail fetchmail || :
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service
if [ -x /usr/bin/systemd-tmpfiles ]; then
	systemd-tmpfiles --create %{name}.conf || :
fi
# Ensure that all files are readable by fetchmail with non-root UID.
touch var/log/fetchmail
chown fetchmail var/log/fetchmail
chmod 0600 var/log/fetchmail

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service
if [ $1 = 0 ]; then
    rm -rf var/lib/fetchmail
fi

%files -f %{name}.lang
%defattr(-, root, root)
%{_bindir}/fetchmail
%dir %attr(0700, fetchmail, root) %{_localstatedir}/lib/fetchmail
%ghost %attr(0600, fetchmail, root) %{_localstatedir}/log/fetchmail
%{_mandir}/man1/fetchmail.1.gz
%doc COPYING FAQ FEATURES NEWS NOTES OLDNEWS README README.NTLM README.SSL README.SSL-SERVER TODO contrib *.html *.txt *.pdf
%ghost %config(noreplace) %attr(0600, fetchmail, root) %{_sysconfdir}/fetchmailrc
%config(noreplace) %{_sysconfdir}/logrotate.d/fetchmail
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%{_libexecdir}/%{name}-systemd-exec
%{_libexecdir}/tmpfiles.d/%{name}.conf
%{_fillupdir}/sysconfig.%{name}

%files -n fetchmailconf
%defattr(-, root, root)
%{_bindir}/fetchmailconf
%{_mandir}/man1/fetchmailconf.1.gz
%{python_sitelib}/fetchmailconf.*

%changelog
* Thu Mar 15 2018 pmonrealgonzalez@suse.com
- Fix fetchmailconf to compile with python{2,3} [bsc#1082694]
  * fetchmail-fetchmailconf-python3-1of3.patch
  * fetchmail-fetchmailconf-python3-2of3.patch
  * fetchmail-fetchmailconf-python3-3of3.patch
* Fri Mar  2 2018 pmonrealgonzalez@suse.com
- By default, the status messages are redirected to
  /var/log/fetchmail. The syslog option or no-logging are also
  available. (bsc#1033081)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Nov 13 2017 vcizek@suse.com
- drop SSLv3 support to build with openssl 1.1 (bsc#1066940)
  * add fetchmail-openssl11.patch
* Fri Apr 28 2017 pmonrealgonzalez@suse.com
- Allow --syslog option in daemon mode (bsc#1033081).
  * By default, the status messages are redirected to the syslog.
* Fri Mar 31 2017 meissner@suse.com
- prerequire group(daemon) to meet new tumbleweed user handling
* Fri May 13 2016 jengelh@inai.de
- Check for user/group existence before attempting to add them,
  and remove error suppression from these calls.
- Ensure tmpfile creation is run
* Fri May 13 2016 pjanouch@suse.de
- Made the helper script introduced in last change return exit status
  5 on configuration errors instead of 1, which should make it a bit
  less confusing (bsc#979534)
* Fri Apr  8 2016 pjanouch@suse.de
- Made /etc/sysconfig/fetchmail work again after a botched systemd
  conversion that ignored the file altogether (bsc#905673)
- Removed the FETCHMAIL_USER setting in favor of editing the
  systemd service file (which should be copied to the respective
  location in /etc, and not edited in-place)
* Thu Jan  8 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove support for <12.3 as it does not build anyway.
- Fix krb5 switches
- Provide proper rcbla controler for the service
* Mon Dec 29 2014 meissner@suse.com
- build with PIE
* Fri Dec  5 2014 lmuelle@suse.com
- Removed executable permission bits from fetchmail.service file.
- Update the project url in the spec file after Berlios shutdown.
- Remove dependency on gpg-offline as signature checking is implemented in the
  source validator.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in postun script
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Sun Oct 27 2013 p.drouand@gmail.com
- Add systemd support for openSUSE >= 12.3
* Mon Apr 29 2013 vcizek@suse.com
- added offline gpg verification
- update to 6.3.26
  [#] CRITICAL BUG FIX for setups using "mimedecode":
  * The mimedecode feature failed to ship the last line of the body if it was
    encoded as quoted-printable and had a MIME soft line break in the very last
    line.  Reported by Lars Hecking in June 2011.
  * Bug introduced on 1998-03-20 when the mimedecode support was added by ESR
    before release 4.4.1 through code contributed by Henrik Storner.
    Workaround for older releases: do not use mimedecode feature.
  * Earlier versions of this NEWS file claimed this bug fixed in fetchmail-6.3.23,
    but it was not.
  * Fixes Launchpad Bug#1171818.
* Tue Mar 19 2013 vcizek@suse.com
- update to 6.3,25
  [#] CRITICAL AND REGRESSION FIXES
  * Plug a memory leak in OpenSSL's certificate verification callback.
  This would affect fetchmail configurations running with SSL in daemon mode
  more than one-shot runs.
  Reported by Erik Thiele, and pinned by Dominik Heeg,
  fixes Debian Bug #688015.
  This bug was introduced into fetchmail 6.3.0 (committed 2005-10-29)
  when support for subjectAltName was added through a patch by Roland
  Stigge, submitted as Debian Bug#201113.
  * The --logfile option now works again outside daemon mode, reported by Heinz
  Diehl. The documentation that I had been reading was inconsistent with the
  code, and only parts of the manual page claimed that --logfile was only
  effective in daemon mode.
  [#] BUG FIXES
  * Fix a memory leak in out-of-memory error condition while handling plugins.
  Report and patch by John Beck (found with Parfait static code analyzer).
  * Fix a NULL pointer dereference in out-of-memory error condition while handling
  plugins.
  Report and patch by John Beck (found with Parfait static code analyzer).
  [#] CHANGES
  * Improved reporting when SSL/TLS X.509 certificate validation has failed,
  working around a not-so-recent swapping of two OpenSSL error codes, and
  a practical impossibility to distinguish broken certification chains from
  missing trust anchors (root certificates).
  * OpenSSL decoded errors are now reported through report(), rather than dumped
  to stderr, so that they should show up in logfiles and/or syslog.
  * The fetchmail manual page no longer claims that MD5 were the default OpenSSL
  hash format (for use with --sslfingerprint). Reported by Jakob Wilk,
  PARTIAL fix for Debian Bug#700266.
  * The fetchmail manual page now refers the user to --softbounce from the
  SMTP/ESMTP ERROR HANDLING section.  Reported by Anton Shterenlikht.
* Tue Dec 11 2012 vcizek@suse.com
- update to 6.3.23
  [#] REGRESSION FIXES
  * Fix compilation with OpenSSL implementations before 0.9.8m that lack
  SSL_CTX_clear_options. Patch by Earl Chew.
  Note that the use of older OpenSSL versions with fetchmail is unsupported and
  * not* recommended.
  [#] BUG FIXES
  * Fix combination of --plugin and -f -. Patch by Alexander Zangerl,
  to fix Debian Bug#671294.
  * Clean up logfile vs. syslog handling, and in case logfile overrides
  syslog, send a message to the latter stating where logging goes.
  [#] CHANGES
  * The build process can now be made a bit more silent and concise through
  ./configure --enable-silent-rules, or by adding "V=0" to the make command.
  [#] WORKAROUNDS
  * Make Maillennium POP3 workarounds less specific, to encompass
  Maillennium POP3/UNIBOX (Maillennium V05.00c++). Reported by Eddie
  via fetchmail-users mailing list, 2012-10-13.
  [#] TRANSLATION UPDATES
* Mon Nov 12 2012 coolo@suse.com
- do not use useradd -o without -u
* Tue Sep 11 2012 vcizek@suse.com
- update to 6.3.22
  [#] SECURITY FIXES
  * CVE-2012-3482 (bnc#775988)
  * CVE-2011-3389
  [#] BUG FIX
  * The Server certificate: message in verbose mode now appears on stdout like the
    remainder of the output. Reported by Henry Jensen, to fix Debian Bug #639807.
  * The GSSAPI-related autoconf code now matches gssapi.c better, and uses
    a different check to look for GSS_C_NT_HOSTBASED_SERVICE.
    This fixes the GSSAPI-enabled build on NetBSD 6 Beta.
  [#] CHANGES
  * The security and errata notices fetchmail-{EN,SA}-20??-??.txt are now
    under the more relaxed CC BY-ND 3.0 license (the noncommercial clause
    was dropped). The Creative Commons address was updated.
  * The Python-related Makefile.am parts were simplified to avoid an automake
    1.11.X bug around noinst_PYTHON, Automake Bug #10995.
  * Configuring fetchmail without SSL now triggers a configure warning,
    and asks the user to consider running configure --with-ssl.
  [#] WORKAROUNDS
  * Some servers, notably Zimbra, return A1234 987 FETCH () in response to
    a header request, in the face of message corruption.  fetchmail now treats
    these as temporary errors. Report and Patch by Mikulas Patocka, Red Hat.
  * Some servers, notably Microsoft Exchange, return "A0009 OK FETCH completed."
    without any header in response to a header request for meeting reminder
    messages (with a "meeting.ics" attachment). fetchmail now treats these as
    transient errors.  Report by John Connett, Patch by Sunil Shetye.
* Thu Jun 14 2012 seife+obs@b1-systems.com
- dont't require, just suggest smtp_daemon -- fetchmail does run
  fine (and much safer) with e.g. procmail as mda.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Tue Aug 30 2011 puzel@suse.com
- repack upstream tarball without fetchmail-{SA,EN}-*.txt
  (bnc#713698)
- add README-security.txt
* Mon Aug 22 2011 puzel@novell.com
- update to fetchmail-6.3.21
  - critical bug fix
  - The IMAP client no longer inserts NUL bytes into the last line
    of a message when it is not closed with a LF or CRLF sequence.
    Reported by Antoine Levitt.  As a side effect of the fix, and
    in order to avoid a full rewrite, fetchmail will now
    CRLF-terminate the last line fetched through IMAP, even if it
    is originally not terminated by LF or CRLF. This bears no
    relevance if your messages end up in mbox, but adds line
    termination for storages (like Maildir) that do not require
    that the last line be LF- or CRLF-terminated.
* Thu Jun 30 2011 cdenicolo@novell.com
- license update:  GPLv2+
  remove licenses " Other uncritical OpenSource License ; Public Domain,
  Freeware"
* Mon Jun  6 2011 puzel@novell.com
- update to fetchmail-6.3.20
  [#] SECURITY BUG FIXES
  - CVE-2011-1947 (bnc#697368): STARTTLS: Fetchmail runs the IMAP
    STARTTLS or POP3 STLS negotiation with the set timeout (default
    five minutes) now. This was reported missing, with observed
    fetchmail freezes beyond a week, by Thomas Jarosch.
    See fetchmail-SA-2011-01.txt for further details.
  [#] BUG FIXES
  - IMAP: Do not search for UNSEEN messages in ranges. Usually,
    there are very few new messages and most of the range searches
    result in nothing. Instead, split the long response to make the
    IMAP driver think that there are multiple lines of response.
  - Do not print "skipping message" for old messages even in
    verbose mode. If there are too many old messages, the logs just
    get filled without any real activity.
  - Build: fetchmail now always uses its own MD5 implementation
    rather than trying to find a system library with matched
    header. The library and header variants found on systems are
    too diverse, and the code size saving is not worth any more
    wasted user or programmer time.
  [#] CHANGES
  - Call strlen() only once when removing CRLF from a line.
  - fetchmail sets Internet domain sockets to "keepalive" mode now.
    Note that there is no portable way to configure actual timeouts
    for this mode, and some systems only support a system-wide
    timeout setting. fetchmail does not attempt to tune the time
    spans of keepalive mode.
- remove build-time dependency on ed
- use spec-cleaner
* Mon Dec 13 2010 puzel@novell.com
- update to fetchmail-6.3.19
  - bugfix release
  * When specifying multiple local multidrop lists, do not lose
    wildcard flag.  (Affects "user foo is bar baz * is joe here")
  * In multidrop configurations, an asterisk can now appear
    anywhere in the list of local users, not just at the end.
  * In multidrop mode, header parsing is now more verbose in -vv
    mode, so that it becomes possible to see which header is used.
  * Make --antispam work from command line (these used to work in
    rcfiles).
  * Smoke test XHTML 1.1 validation, and if it fails, skip
    validating HTML documents.  Skip validating
    Mailbox-Names-UTF7.html. Several systems have broken XHTML 1.1
    DTD installations that jeopardize the build.
  * Send a NOOP only after a failed STARTTLS in IMAP.
  * GSSAPI verbose/debug syslog to INFO severity.  Do STARTTLS/STLS
    negotiation in IMAP/POP3 if it is mandatory even if the server
    capabilities do not show support for upgradation to TLS.  To
    use this, configure --sslproto tls1.
  * IMAP: Understand empty strings as FETCH response, seen on
    Yahoo.  Note that fetchmail continues to expect literals as
    FETCH response for now.
* Mon Oct 11 2010 puzel@novell.com
- update to fetchmail-6.3.18
  [#] SECURITY IMPROVEMENTS TO DEFANG X.509 CERTIFICATE ABUSE
  * Fetchmail now only accepts wildcard certificate common names
    and subject alternative names if they start with "*.". Previous
    versions would accept wildcards even if no period followed
    immediately.
  * Fetchmail now disallows wildcards in certificates to match
    domain literals (such as 10.9.8.7), or wildcards in domain
    literals ("*.168.23.23").  The test is overly picky and
    triggers if the pattern (after skipping the initial wildcard
    "*") or domain consists solely of digits and dots, and thus
    matches more than needed.
  * Fetchmail now disallows wildcarding top-level domains.
  [#] CRITICAL BUG FIXES AND REGRESSION FIXES
  * Fetchmail 6.3.15, 6.3.16, and 6.3.17 would pick up libmd5 to
    obtain MD5* functions, as an effect of an undocumented Solaris
    MD5 fix.  This caused all MD5-related functions to malfunction
    if, for instance, libmd5.so was installed on other operating
    systems as part of libwww on machines where long isn't
    32-bits, i. e.  usually on 64-bit computers.
  * Fetchmail 6.3.17 warned about insecure SSL/TLS connections
    even if a matching --sslfingerprint was specified. This is an
    omission from an SSL usability change made in 6.3.17.
  * Fetchmail will now apply timeouts to the authentication stage.
    This stage encompasses STARTTLS/STLS negotiation in IMAP/POP3.
    Reported missing by Thomas Jarosch.
  * Fetchmail now cancels GSSAPI authentication properly when
    encountering GSS errors, such as no or unsuitable credentials.
    It now sends an asterisk on a line by its own, as required in
    SASL.  This fixes protocol synchronization issues that cause
    Authentication failures, often observed with kerberized MS
    Exchange servers.
  * Other fixes.
* Tue Aug 17 2010 puzel@novell.com
- update to fetchmail-6.3.17
  [#] SECURITY FIX
  * CVE-2010-1167: Fetchmail before release 6.3.17 did not properly
    sanitize external input (mail headers and UID).
  [#] FEATURES
  * Fetchmail now supports a --sslcertfile <file> option to
    specify a "CA bundle" file (a file that contains trusted CA
    certificates).
  * Fetchmail now supports a
    FETCHMAIL_INCLUDE_DEFAULT_X509_CA_CERTS environment variable
    to force loading the default SSL CA certificate locations even
    if --sslcertfile or --sslcertpath is used.  If neither option
    is in effect, fetchmail loads the default locations.
  [#] REGRESSION FIX
  * Fix string handling in rcfile scanner, which caused fetchmail
    to misparse a run control file in certain circumstances.
  [#] BUG FIXES
  * Plug memory leak when using a "defaults" entry in the run
    control file.
  * Do not print SSL certificate mismatches unless verbose or
  - -sslcertck is enabled.
  * Do not lose "set invisible" in fetchmailconf. (Michael Barnack)
- drop fetchmail-SA-2010-02.patch (in upstream)
* Mon Apr 19 2010 puzel@novell.com
- add fetchmail-SA-2010-02.patch (bnc#597673)
* Wed Apr 14 2010 puzel@novell.com
- make it possible change default fetchmailrc location using new
  sysconfig option
- do not change owner of fetchmailrc in post
* Wed Apr  7 2010 puzel@novell.com
- update to fetchmail-6.3.16
  [#] BUG FIX
  * Fix --interface option, broken in 6.3.15.
  [#] CHANGE
  * Call OpenSSL_add_all_algorithms(). This is needed to support
    non-mandatory algorithms in certificates.
* Mon Mar 29 2010 puzel@novell.com
- update to fetchmail-6.3.15
  [#] FEATURE
  * Fetchmail now supports a bad-header command line or rcfile
    option that takes exactly one argument, accept or reject
    (default).
  [#] BUG FIXES
  * In the rcfile, recognize "local" as abbreviation for
    "localdomains", as documented.
  * Do not close stdout when using mda and "bsmtp -" at the same time.
  * Log operating system errors when BSMTP writes fail.
  * Fix verbose mode progress formatting regression from 6.3.10;
    SMTP trace lines were no longer on a line of their own. Reported
    by Melchior Franz.
  * Check seteuid() return value and abort running MDA if switch fails.
  * Set global flags in a consistent manner. Make --nosoftbounce and
  - -nobounce work from command line (these used to work in rcfiles).
    Reported and fix confirmed working by N.J. Mann. (Sunil Shetye)
* Fri Feb  5 2010 puzel@novell.com
- update to fetchmail-6.3.14
  [#] SECURITY FIXES
  * SSL/TLS certificate information is now also reported properly
    on computers that consider the "char" type signed. Fixes
    malloc() buffer overrun.  Workaround for older versions: do not
    use verbose mode.
  [#] BUG FIXES
  * The IMAP client no longer skips messages from several IMAP
    servers including Dovecot if fetchmail's "idle" is in use.
    Causes were that fetchmail (a) ignored some untagged responses
    when it should not (b) relied on EXISTS messages in response to
    EXPUNGE, which aren't mandated by RFC-3501 (the IMAP standard)
    and aren't sent by Dovecot either. Fix by Sunil Shetye (the fix
    also consolidates IMAP response handling, improving overall
    robustness of the IMAP client), bug report and testing by Matt
    Doran, with further hints from Timo Sirainen.
  * The SMTP client now recovers from errors (such as servers
    dropping the connection after errors) when sending an RSET
    command.  Fix by Sunil Shetye. Report by James Moe.
  * The IMAP client now uses "SEARCH UNSEEN" rather than "SEARCH
    UNSEEN NOT DELETED" again on IMAP2, to fix a regression in
    fetchmail 6.2.5 reported by Will Stringer in June 2004. (Sunil
    Shetye)
  * The IMAP client now uses "SEARCH UNSEEN UNDELETED" on IMAP4
    and IMAP4r1 servers (Sunil Shetye).
  * Workaround: The IMAP client now falls back to "FETCH n:m
    FLAGS" if the server does not support "SEARCH". (Sunil Shetye)
  * The IMAP client now requests message numbers in batches of
    1,000 to avoid problems if there are more than 1860 unseen
    messages. (Sunil Shetye) Note that this wasn't security
    relevant because fetchmail would only read up to the maximum
    buffer size and leave the remainder of the string unread, going
    out of synch afterwards.
  * Stricter validation of IMAP responses containing byte or
    message counts.
- fetchmail 6.3.13 :
  [#] REGRESSION FIXES
  * The multiline SMTP error fix in release 6.3.12 caused
    fetchmail to lose message codes 400..599 and treat all of these
    as temporary error. This would cause messages to be left on the
    server even if softbounce was turned off.  Reported by Thomas
    Jarosch.
* Fri Nov 13 2009 puzel@novell.com
- update to fetchmail-6.3.12
  [#] REGRESSION FIXES
  * The CVS-2009-2666 fix in fetchmail release 6.3.11 caused a free() of
    unallocated memory on SSL connections, which caused crashes or program aborts
    on some systems (depending on how initialization and free() of unallocated
    memory is handled in compiler and libc).
    Workaround for older versions: run in verbose mode.
    Patch courtesy of Thomas Heinz, fixes Gentoo Bug #280760.
    This regression affected only the 6.3.11 release, but not the patch that was
    part of the security announcement fetchmail-SA-2009-01.
  [#] BUG FIXES
  * Fix error reporting for GSSAPI on Heimdal (h5l) Kerberos.
  * Look for MD5_Init in libcrypto rather than libssl, fixes Gentoo Kerberos
    builds; fixes upstream parts of Gentoo Bugs #231400 and #185652, and fixes
    BerliOS Bug #16134.
  * Report multiline SMTP errors properly, reported by Earl Chew; fixes Debian Bug
    [#569899], reported by Akihiro Terasaki.
    Note: This fix introduced a regression, fixed in 6.3.13.
  * Replace control characters in SMTP replies by '?'.
  * Fetchmailconf: Fix descriptions for smtpaddress and smtpname options;
    smtpaddress is for RCPT TO, not MAIL FROM. Found by Gerard Seibert.
- update to fetchmail-6.3.13
  [#] REGRESSION FIXES
  * The multiline SMTP error fix in release 6.3.12 caused fetchmail to lose
    message codes 400..599 and treat all of these as temporary error. This would
    cause messages to be left on the server even if softbounce was turned off.
    Reported by Thomas Jarosch.
- drop fetchmail-6.3.11-fix-invalid-free.patch (fixed upstream)
* Mon Aug 10 2009 puzel@novell.com
- add fetchmail-6.3.11-fix-invalid-free.patch
  - fix https://bugs.gentoo.org/280760
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Thu Aug  6 2009 puzel@novell.com
- update to 6.3.11
  [#] SECURITY BUGFIXES
  * CVE-2009-2666: SSL NUL prefix impersonation attack through NULs in a
    part of a X.509 certificate's CommonName and subjectAltName fields. These
    fields use opaque strings with a separate length field, so that the NUL
    character isn't a special character inside the certificate. Fetchmail, being
    written in the C language, used to treat these strings as C strings
    nonetheless, so that the domain comparison would end at the first embedded NUL
    character, rather than at the real end of the string.
    Fetchmail will now abort certificate verification as failed if NULs are
    encountered inside either of these fields regardless of their position, and
    drop the connection even if --sslcertck is not used, because NUL is not a
    valid character in legitimate DNS names.
    See fetchmail-SA-2009-01.txt for details, including a minimal patch.
  [#] BUGFIXES
  * Remove the spurious message "message delimiter found while scanning headers".
    RFC-5322 syntax states that the delimiter is part of the body, and the body is
    optional.
  * Convert all non-printable characters in certificate Subject/Issuer
    Common Name or Subject Alternative Name fields to ANSI-C hex escapes (\xnn,
    where nn are hex digits).
* Fri Jul  3 2009 puzel@novell.com
- update to 6.3.10 (final version)
* Mon Jun  1 2009 puzel@suse.cz
- update to 6.3.10-beta1
  [#] INCOMPATIBLE BUGFIXES AND CHANGES:
  * Fetchmail no longer drops permanently undelivered messages by default, to
    match historic documentation.  It does this by adding a new "softbounce"
    option, see below.
  * There is a new "softbounce" global option that prevents the deletion of
    messages that have not been forwarded. It defaults to "true" for fetchmail
    6.3.X in order to match historic documentation. This may change its default
    in the next major release.
  * For other changes, please see the package changelog
- update fetchmail-6.3.8-smtp_errors.patch (partially upstreamed)
* Tue Jan 13 2009 puzel@suse.cz
- update to 6.3.9 final
  - deleted fetchmail-fix-permissions-doc.patch (fixed upstream)
* Mon Jan 12 2009 puzel@suse.cz
- fix spurious messages from fetchmail.init (bnc#464037)
* Fri Nov 14 2008 mrueckert@suse.de
- make the kerberos handling based on suse_version instead
  of sles_version
* Thu Oct  9 2008 puzel@suse.cz
- fix documentation inconsistency (bnc#174287)
- mark /etc/logrotate.d/fetchmail as %%config(noreplace)
* Wed Oct  1 2008 puzel@suse.cz
- Fix build on SLE9
  - do not build with kerberos support on SLE9
* Tue Sep  9 2008 kukuk@suse.de
- Remove support for dante (deprecated, homepage not reacheable,...)
* Thu Sep  4 2008 puzel@suse.cz
- update to 6.3.9rc2
  - bugfix release, see package changelog for details
- removed fetchmail-6.3.8-CVE-2007-4565.patch (fixed in upstream)
- removed fetchmail-6.3.8-long_headers_segfault.patch (fixed in upstream)
* Fri Aug 22 2008 puzel@suse.cz
- fix build on SLE10
  - do not run autoreconf if suse_version < 1010
* Thu Jul 24 2008 puzel@suse.cz
- specfile cleanup and rpmlint warning fixes
  * removed obsolete 'Provides: pop'
  * added logrotate dependency
  * removed unnecessary python dependency
  * removed unnecessary 'export CFLAGS="$RPM_OPT_FLAGS"'
  - %%configure macro should suffice
- initscript fixes
  * obsolete X-UnitedLinux-Should-Start replaced by
    Should-Start
  * same with Should-Stop
  * added $remote-fs dependency
* Tue Jul  1 2008 puzel@suse.cz
- updated fetchmail-6.3.8-long_headers_segfault.patch from upstream
* Tue Jun 17 2008 puzel@suse.cz
- kerberos (krb5) support enabled [bnc#353817]
* Wed May 28 2008 puzel@suse.cz
- fixed broken oneshot option in initscript [bnc#360507]
* Thu May 22 2008 puzel@suse.cz
- fixed bnc#354291
  * caused segmentation fault when retrieving mail with long To:
    headers
* Wed Apr 30 2008 pcerny@suse.cz
- added option to specify polling interval to init script
* Fri Mar 28 2008 pcerny@suse.cz
- additional fix for bnc#246829
  [fetchmail-6.3.8-starttls.patch ->
  fetchmail-6.3.8-smtp_errors.patch]
* Wed Nov 28 2007 pv@suse.de
- add PreReq pwdutils #327550 - yast2-mail fetchmail error
* Thu Sep 27 2007 pcerny@suse.de
- Fix for DoS vulnerability (#308271 CVE-2007-4565)
- Do not remove messages if SMTP insists on TLS (#246829)
  [fetchmail-6.3.8-starttls.patch]
* Tue Sep 11 2007 ro@suse.de
- remove librsaref2-devel from buildrequires (unused)
* Fri Aug 31 2007 pcerny@suse.cz
- librsaref2 => librsaref2-devel [#302599]
- removed %%suseversion > 800 check (insserv)
* Mon Jul  2 2007 lrupp@suse.de
- rsaref => librsaref2
* Thu Apr 19 2007 sbrabec@suse.cz
- Updated to version 6.3.8:
  * Make the APOP challenge parser more distrustful and have it
    reject challenges that do not conform to RFC-822 msg-id format
    (CVE-2007-1558).
  * Repoll immediately if a protocol error happens during the
    authentication attempt after a failed opportunistic TLS upgrade
    (#262450).
  * Do not crash with a null pointer dereference when opening the
    BSMTP file fails.
  * Make BSMTP output actually work.
  * Add delete-later and delete-later.README.
  * Fix KPOP.
  * Fix repoll when server disconnects after opportunistic TLS
    failed for POP3.
  * Documentation and string fixes.
* Fri Mar 30 2007 ro@suse.de
- added pwdutils to buildreq
* Tue Feb  6 2007 sbrabec@suse.cz
- Repair repoll after opportunistic TLS failed (#223507#c27,
  Berlios#10133).
- Use upstream fix of KPOP regression (#223507#c26).
* Thu Jan 25 2007 sbrabec@suse.cz
- Fixed regression in KPOP support (#223507#c8).
  http://lists.berlios.de/pipermail/fetchmail-devel/2007-January/000857.html
* Wed Jan 24 2007 sbrabec@suse.cz
- Updated to version 6.3.6 (#223507):
  * Password disclosure vulnerability fixed (CVE-2006-5867).
  * Repairs a regression in 6.3.5 that crashes fetchmail when a
    message with invalid headers is found while fetchmail's mda
    option is in use (CVE-2006-5974).
  * Repair --logfile, broken in 6.3.5.
  * Repair --user, broken in 6.3.5.
  * RPOP: used to log the password locally rather than an asterisk
    as the other protocols do.
  * POP3: Probes capabilities now when Kerberos V5 is enabled, so
    that we can actually detect if the server supports it.
  * DNS: Detect /etc/resolv.conf changes
  * When HOME and FETCHMAILHOME are unset, be sure to copy user
    database information.
- Spec file cleanup.
* Wed Oct 25 2006 sbrabec@suse.cz
- Fixed problems caused by calling daemon as non-root (#207305).
* Mon Oct 23 2006 sbrabec@suse.cz
- Updated to version 6.3.5:
  * Bug fixes.
  * Translation updates.
  * Logging behavior changes.
  * fetchmail now supports foo@example.org=bar user mappings for
    multidrop boxes.
  * Bouncing improvements.
  * Improved IMAP and SDPS behavior.
  * See NEWS for deprecated features and major incompatible change
    advance warnings.
* Sat Oct 21 2006 schwab@suse.de
- Run automake.
* Thu Jun  1 2006 sbrabec@suse.cz
- By default run as non-root user fetchmail (159764#c1).
- Implemented "oneshot" in the init script (159764#c8).
* Mon Apr  3 2006 sbrabec@suse.cz
- Backported fixes for two crashes (159764#c9, 159764#c10).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 sbrabec@suse.cz
- Updated to version 6.3.2 (fixes CVE-2006-0321).
* Tue Jan 10 2006 sbrabec@suse.cz
- Updated to version 6.3.1 (fixes #140475).
* Mon Dec  5 2005 sbrabec@suse.cz
- Updated to version 6.3.0 (fixes #131232).
* Wed Jul 27 2005 sbrabec@suse.cz
- Updated to version 6.2.5.2 (#97555).
* Mon Apr 25 2005 sbrabec@suse.cz
- Prevent lost mails with NULL envelope (#80331).
* Thu Feb  3 2005 ro@suse.de
- fix build on older distributions
* Wed Jan 19 2005 sbrabec@suse.cz
- Turned on GSSAPI, SOCKS and RSAREF support.
- Fixed implicit declaration and random result warnings.
* Fri Sep 24 2004 sbrabec@suse.cz
- Added more sysconfig options for init script.
* Thu Sep 16 2004 aj@suse.de
- Remove wrong definition.
* Tue Aug 31 2004 sbrabec@suse.cz
- Added sendmail to Required-Start/Stop (#44500).
* Wed May  5 2004 sbrabec@suse.cz
- Added sysconfig variable for polling interval (#39777).
- Init script adapted to conform latest LSB.
* Mon Apr 26 2004 ro@suse.de
- fix missing return value in pop2.c
* Tue Mar 30 2004 sbrabec@suse.cz
- Added /etc/fetchmailrc to file list.
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Mar 10 2004 sbrabec@suse.cz
- Set fetchsizelimit for APOP and RPOP (bug #35555).
  http://lists.ccil.org/pipermail/fetchmail-friends/2003-October/003958.html
* Wed Feb  4 2004 sbrabec@suse.cz
- Updated to version 6.2.5.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Oct 23 2003 kukuk@suse.de
- Remove wrong requires
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 6.2.3.
* Tue May 20 2003 mmj@suse.de
- Fix typo
* Wed Mar 26 2003 sbrabec@suse.cz
- Updated to version 6.2.2.
- Created startup script.
* Thu Jan 16 2003 sbrabec@suse.cz
- Updated to version 6.2.1.
* Fri Dec 13 2002 mmj@suse.de
- Update to 6.2.0 which has security fix for rfc822.c and some
  translations plus an SMTP timeout patch
* Tue Dec 10 2002 sbrabec@suse.cz
- Updated to version 6.1.3.
* Wed Nov 20 2002 sbrabec@suse.cz
- Spec file cleanup (bug #21912).
* Thu Oct 24 2002 sbrabec@suse.cz
- Update to version 6.1.1.
* Tue Oct  1 2002 sbrabec@suse.cz
- Removed --with-included-gettext and re-enabled NLS.
- OPIE/OTP fixes.
- Spec file cleanup.
* Fri Sep 27 2002 mmj@suse.de
- Update to 6.1.0 including since 5.9.13:
  o Support for STARTTLS over IMAP
  o Cleanups and bugfixes
  o Translation update
  o Fix for potential remote vulnerability in multidrop mode,
    which according to the author is an important security fix.
* Mon Jul 29 2002 jreuter@suse.de
- more spec file cleanup
* Mon Jul 29 2002 jreuter@suse.de
- added /etc/logrotate.d/fetchmail (Bugzilla #17279)
- spec file cleanup
* Fri Jul 19 2002 jreuter@suse.de
- removed /usr/share/locale/*/LC_MESSAGES/fetchmail.mo from file list
* Wed Jul 17 2002 jreuter@suse.de
- updated to version 5.9.13
- disabled NLS support because it doesn't compile and esr is about
  to remove it anyway
- complete changelog: http://tuxedo.org/~esr/fetchmail/NEWS
* Sat Mar 23 2002 kukuk@suse.de
- Fix fetchmailconf (wrong python widget destroy calls) [Bug #15391]
* Mon Sep 17 2001 bjacke@suse.de
- minor fixes in README.SUSE
* Thu Aug 16 2001 bjacke@suse.de
- update to 5.9.0
* Thu Jul 12 2001 bjacke@suse.de
- update to 5.8.14
* Thu Jun 14 2001 bjacke@suse.de
- patch to prevent buffer overflow due to long headers
* Tue Apr  3 2001 bjacke@suse.de
- update to 5.8.0
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Feb 14 2001 bjacke@suse.de
- updated to 5.6.5 (fixes #6245)
- fix fetchmailconf nospambounce problem
- enable RPA protocol
* Fri Jan  5 2001 bjacke@suse.de
- disabled IPv6 support for the time being to fix bug #5111
* Wed Dec 20 2000 garloff@suse.de
- pass --enable-NTLM to configure in order to enable M$ Exchange
  compatible auth proto
- explicitly specify the directories with --mandir etc ...
- Use DESTDIR= instead of prefix to pass RPM_BUILD_ROOT
- add %%{?suse_update_config}
* Mon Dec 18 2000 bjacke@suse.de
- some spec file fixes
* Mon Dec 18 2000 ro@suse.de
- Fix requires for fetchmailconf (again)
* Mon Dec 18 2000 bjacke@suse.de
- merged ssl stuff from fetchmailssl to fetchmail package
* Wed Nov 29 2000 bjacke@suse.de
- updated to 5.6.0
- adjust README to new boot concept
* Fri Nov 10 2000 bjacke@suse.de
- updated to version 5.5.5
- switched to long names
- added README.SuSE
* Sun Sep  3 2000 bjacke@suse.de
- update to fetchmail-5.5.1
* Tue May 23 2000 bk@suse.de
- moved fetchmailconf man page to subpackage fetchmcf
* Mon May 15 2000 bk@suse.de
- update to fetchmail-5.4.0, new major version.
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Thu Feb 24 2000 dipa@suse.de
- update to fetchmail-5.3. update to fetchmail-5.3.00
* Tue Feb 15 2000 bk@suse.de
- update to fetchmail-5.2.8, that's the code freeze release for 5.3.0
* Tue Feb  8 2000 bk@suse.de
- update to fetchmail-5.2.7, Eric's changelog to 5.2.6 is very small:
  * Updated FAQ and
  * Updated es.po.
  * Disable mail notification on server unreachable.  This turned out to
    be a very bad idea.
* Tue Feb  1 2000 ro@suse.de
- specfile typo
* Mon Jan 31 2000 ro@suse.de
- create man directory
* Mon Jan 31 2000 bk@suse.de
- restarted spec from package-provided spec, subpackages fetchmcf (fetchmailconf)
* Wed Oct 20 1999 bk@suse.de
- split-off from pop, update to 5.1.2
